@@ -1,12 +1,16 @@
 /*
- *  $Id: defLoad.c,v 4.9 2006/01/24 23:22:16 bkorb Exp $
+ *  $Id: defLoad.c,v 4.11 2006/11/27 01:52:22 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-11-26 15:31:18 bkorb"
+ *  Last Committed:    $Date: 2006/11/27 01:52:22 $
+ *
  *  This module loads the definitions, calls yyparse to decipher them,
  *  and then makes a fixup pass to point all children definitions to
  *  their parent definition.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -313,6 +317,7 @@ readDefines( void )
             return;
         }
 
+    accept_fifo:
         outTime  = time( NULL );
         dataSize = 0x4000 - (4+sizeof( *pBaseCtx ));
         useStdin = AG_TRUE;
@@ -330,6 +335,9 @@ readDefines( void )
                             pzDefFile, strerror( errno )));
 
         if (! S_ISREG( stbf.st_mode )) {
+            if (S_ISFIFO(stbf.st_mode))
+                goto accept_fifo;
+
             errno = EINVAL;
             AG_ABEND( aprf( zCannot, errno, "open non-regular file",
                             pzDefFile, strerror( errno )));
@@ -386,7 +394,7 @@ readDefines( void )
      *  Read until done...
      */
     for (;;) {
-        size_t rdct = fread( (void*)pzData, 1, sizeLeft, fp );
+        size_t rdct = fread((void*)pzData, (size_t)1, sizeLeft, fp);
 
         /*
          *  IF we are done,
@@ -414,6 +422,7 @@ readDefines( void )
          */
         if (sizeLeft == 0) {
             tScanCtx* p;
+            off_t dataOff;
 
             /*
              *  IF it is a regular file, then we are done
@@ -426,9 +435,9 @@ readDefines( void )
              *  Try to reallocate our input buffer.
              */
             dataSize += (sizeLeft = 0x1000);
-            p = (tScanCtx*)AGREALOC( (void*)pBaseCtx,
-                                     dataSize+4+sizeof( *pBaseCtx ),
-                                     "expanded file buffer" );
+            dataOff = pzData - pBaseCtx->pzData;
+            p = AGREALOC( (void*)pBaseCtx, dataSize+4+sizeof( *pBaseCtx ),
+                          "expanded file buffer" );
 
             /*
              *  The buffer may have moved.  Set the data pointer at an
@@ -438,7 +447,7 @@ readDefines( void )
             if (p != pBaseCtx) {
                 p->pzScan = \
                 p->pzData = (char*)(p+1);
-                pzData = p->pzData + (pzData - pBaseCtx->pzData);
+                pzData = p->pzData + dataOff;
                 pBaseCtx = p;
             }
         }
@@ -473,7 +482,6 @@ unloadDefs( void )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/defLoad.c */
