@@ -1,7 +1,7 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (defParse-fsm.c)
  *  
- *  It has been AutoGen-ed  Saturday October 14, 2006 at 04:42:41 PM PDT
+ *  It has been AutoGen-ed  Saturday January 27, 2007 at 07:01:21 AM PST
  *  From the definitions    defParse.def
  *  and the template file   fsm
  *
@@ -133,9 +133,9 @@ dp_trans_table[ DP_STATE_CT ][ DP_EVENT_CT ] = {
   { { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  autogen */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  definitions */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  End-Of-File */
-    { DP_ST_NEED_SEMI, &dp_do_tpl_name },           /* EVT:  var_name */
-    { DP_ST_NEED_SEMI, &dp_do_tpl_name },           /* EVT:  other_name */
-    { DP_ST_NEED_SEMI, &dp_do_tpl_name },           /* EVT:  string */
+    { DP_ST_NEED_SEMI, dp_do_tpl_name },            /* EVT:  var_name */
+    { DP_ST_NEED_SEMI, dp_do_tpl_name },            /* EVT:  other_name */
+    { DP_ST_NEED_SEMI, dp_do_tpl_name },            /* EVT:  string */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  here_string */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  number */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  ; */
@@ -168,8 +168,8 @@ dp_trans_table[ DP_STATE_CT ][ DP_EVENT_CT ] = {
   /* STATE 4:  DP_ST_NEED_NAME */
   { { DP_ST_NEED_DEF, NULL },                       /* EVT:  autogen */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  definitions */
-    { DP_ST_DONE, &dp_do_need_name_end },           /* EVT:  End-Of-File */
-    { DP_ST_HAVE_NAME, &dp_do_need_name_var_name }, /* EVT:  var_name */
+    { DP_ST_DONE, dp_do_need_name_end },            /* EVT:  End-Of-File */
+    { DP_ST_HAVE_NAME, dp_do_need_name_var_name },  /* EVT:  var_name */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  other_name */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  string */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  here_string */
@@ -178,7 +178,7 @@ dp_trans_table[ DP_STATE_CT ][ DP_EVENT_CT ] = {
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  = */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  , */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  { */
-    { DP_ST_HAVE_VALUE, &dp_do_end_block },         /* EVT:  } */
+    { DP_ST_HAVE_VALUE, dp_do_end_block },          /* EVT:  } */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  [ */
     { DP_ST_INVALID, &dp_do_invalid }               /* EVT:  ] */
   },
@@ -192,8 +192,8 @@ dp_trans_table[ DP_STATE_CT ][ DP_EVENT_CT ] = {
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  string */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  here_string */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  number */
-    { DP_ST_NEED_NAME, &dp_do_empty_val },          /* EVT:  ; */
-    { DP_ST_NEED_VALUE, &dp_do_have_name_lit_eq },  /* EVT:  = */
+    { DP_ST_NEED_NAME, dp_do_empty_val },           /* EVT:  ; */
+    { DP_ST_NEED_VALUE, dp_do_have_name_lit_eq },   /* EVT:  = */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  , */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  { */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  } */
@@ -205,15 +205,15 @@ dp_trans_table[ DP_STATE_CT ][ DP_EVENT_CT ] = {
   { { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  autogen */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  definitions */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  End-Of-File */
-    { DP_ST_HAVE_VALUE, &dp_do_str_value },         /* EVT:  var_name */
-    { DP_ST_HAVE_VALUE, &dp_do_str_value },         /* EVT:  other_name */
-    { DP_ST_HAVE_VALUE, &dp_do_str_value },         /* EVT:  string */
-    { DP_ST_HAVE_VALUE, &dp_do_str_value },         /* EVT:  here_string */
-    { DP_ST_HAVE_VALUE, &dp_do_str_value },         /* EVT:  number */
+    { DP_ST_HAVE_VALUE, dp_do_str_value },          /* EVT:  var_name */
+    { DP_ST_HAVE_VALUE, dp_do_str_value },          /* EVT:  other_name */
+    { DP_ST_HAVE_VALUE, dp_do_str_value },          /* EVT:  string */
+    { DP_ST_HAVE_VALUE, dp_do_str_value },          /* EVT:  here_string */
+    { DP_ST_HAVE_VALUE, dp_do_str_value },          /* EVT:  number */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  ; */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  = */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  , */
-    { DP_ST_NEED_NAME, &dp_do_start_block },        /* EVT:  { */
+    { DP_ST_NEED_NAME, dp_do_start_block },         /* EVT:  { */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  } */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  [ */
     { DP_ST_INVALID, &dp_do_invalid }               /* EVT:  ] */
@@ -223,11 +223,11 @@ dp_trans_table[ DP_STATE_CT ][ DP_EVENT_CT ] = {
   { { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  autogen */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  definitions */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  End-Of-File */
-    { DP_ST_NEED_CBKT, &dp_do_indexed_name },       /* EVT:  var_name */
+    { DP_ST_NEED_CBKT, dp_do_indexed_name },        /* EVT:  var_name */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  other_name */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  string */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  here_string */
-    { DP_ST_NEED_CBKT, &dp_do_indexed_name },       /* EVT:  number */
+    { DP_ST_NEED_CBKT, dp_do_indexed_name },        /* EVT:  number */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  ; */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  = */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  , */
@@ -264,7 +264,7 @@ dp_trans_table[ DP_STATE_CT ][ DP_EVENT_CT ] = {
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  string */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  here_string */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  number */
-    { DP_ST_NEED_NAME, &dp_do_empty_val },          /* EVT:  ; */
+    { DP_ST_NEED_NAME, dp_do_empty_val },           /* EVT:  ; */
     { DP_ST_NEED_VALUE, NULL },                     /* EVT:  = */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  , */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  { */
@@ -284,7 +284,7 @@ dp_trans_table[ DP_STATE_CT ][ DP_EVENT_CT ] = {
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  number */
     { DP_ST_NEED_NAME, NULL },                      /* EVT:  ; */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  = */
-    { DP_ST_NEED_VALUE, &dp_do_next_val },          /* EVT:  , */
+    { DP_ST_NEED_VALUE, dp_do_next_val },           /* EVT:  , */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  { */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  } */
     { DP_ST_INVALID, &dp_do_invalid },              /* EVT:  [ */
@@ -371,12 +371,19 @@ dp_do_empty_val(
     te_dp_event trans_evt )
 {
 /*  START == EMPTY VAL == DO NOT CHANGE THIS COMMENT  */
+    static char * nil_pz = NULL;
+
     /*
      *  Our state is either "have-name" or "indx-name" and we found a ';',
      *  end of statement.  It is a string value with an empty string.
      */
     tDefEntry* pDE = findPlace( pz_new_name, NULL );
-    pDE->val.pzText = (char*)zNil;
+    if (nil_pz == NULL) {
+        nil_pz = AGALOC( 1, "NUL byte" );
+        *nil_pz = NUL;
+    }
+
+    pDE->val.pzText = nil_pz;
     pDE->valType    = VALTYP_TEXT;
     return maybe_next;
 /*  END   == EMPTY VAL == DO NOT CHANGE THIS COMMENT  */
