@@ -1,6 +1,9 @@
 
 /*
- *  $Id: expOutput.c,v 4.15 2006/08/01 20:31:04 bkorb Exp $
+ *  $Id: expOutput.c,v 4.21 2006/11/27 01:52:22 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-11-26 15:38:29 bkorb"
+ *  Last Committed:    $Date: 2006/11/27 01:52:22 $
  *
  *  This module implements the output file manipulation function
  */
@@ -103,7 +106,7 @@ addWriteAccess( char* pzFileName )
 /*=gfunc out_delete
  *
  * what: delete current output file
- * doc:  
+ * doc:
  *  Remove the current output file.  Cease processing the template for
  *  the current suffix.  It is an error if there are @code{push}-ed
  *  output files.  Use the @code{(error "0")} scheme function instead.
@@ -156,7 +159,7 @@ ag_scm_out_move( SCM new_file )
  *
  * what:   close current output file
  * exparg: disp, return contents of the file, optional
- * doc:  
+ * doc:
  *  If there has been a @code{push} on the output, then close that
  *  file and go back to the previously open file.  It is an error
  *  if there has not been a @code{push}.  @xref{output controls}.
@@ -177,9 +180,9 @@ ag_scm_out_pop( SCM ret_contents )
         unsigned long pos = ftell( pCurFp->pFile );
 
         if (pos != 0) {
-            char* pz = ag_scribble( pos );
+            char* pz = ag_scribble( (size_t)pos );
             rewind( pCurFp->pFile );
-            if (fread( pz, pos, 1, pCurFp->pFile ) != 1)
+            if (fread( pz, (size_t)pos, (size_t)1, pCurFp->pFile ) != 1)
                 AG_ABEND( aprf( "Error %d (%s) rereading output\n",
                                 errno, strerror( errno )));
             res = AG_SCM_STR2SCM( pz, pos );
@@ -196,7 +199,7 @@ ag_scm_out_pop( SCM ret_contents )
  *
  * what:   suspend current output file
  * exparg: suspName, A name tag for reactivating
- * doc:  
+ * doc:
  *  If there has been a @code{push} on the output, then set aside the
  *  output descriptor for later reactiviation with @code{(out-resume "xxx")}.
  *  The tag name need not reflect the name of the output file.  In fact,
@@ -236,7 +239,7 @@ ag_scm_out_suspend( SCM suspName )
  *
  * what:   resume suspended output file
  * exparg: suspName, A name tag for reactivating
- * doc:  
+ * doc:
  *  If there has been a suspended output, then make that output descriptor
  *  current again.  That output must have been suspended with the same tag
  *  name given to this routine as its argument.
@@ -287,7 +290,7 @@ ag_scm_out_resume( SCM suspName )
 SCM
 ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
 {
-    static const char invalid_z[] = "ag-fprintf: 'port' is invalid";
+    static char const invalid_z[] = "ag-fprintf: 'port' is invalid";
     int   list_len = scm_ilength( alist );
     char* pzFmt    = ag_scm2zchars( fmt, zFormat );
     SCM   res      = run_printf( pzFmt, list_len, alist );
@@ -316,7 +319,7 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
      *  "0" (zero) representing the current output and "1" the last suspended
      *  output.  If the number is out of range, we'll fall through to the abend.
      */
-    else if (AG_SCM_NUMBER_P(port)) do {
+    else if (AG_SCM_NUM_P(port)) do {
         tFpStack* pSaveFp = pCurFp;
         unsigned long val = gh_scm2ulong(port);
 
@@ -331,13 +334,13 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
         (void) ag_scm_emit( res );
         pCurFp  = pSaveFp;
         return SCM_UNDEFINED;
-        
+
+    fprintf_woops: ;
     } while (0);
 
     /*
      *  Still here?  We have a bad "port" specification.
      */
- fprintf_woops:
     AG_ABEND( invalid_z );
     /* NOTREACHED */
     return SCM_UNDEFINED;
@@ -349,7 +352,7 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
  * what:   append output to file
  * exparg: file-name, name of the file to append text to
  *
- * doc: 
+ * doc:
  *  Identical to @code{push-new}, except the contents are @strong{not}
  *  purged, but appended to.  @xref{output controls}.
 =*/
@@ -456,7 +459,7 @@ ag_scm_out_push_new( SCM new_file )
          *  "fopencookie" nor "funopen" is available in the local C library.
          *  We reach here if --no-fmemopen was *not* on the command line.
          */
-        p->pFile  = ag_fmemopen( NULL, 0, "wb+" );
+        p->pFile  = ag_fmemopen(NULL, (size_t)0, "wb+");
         pzNewFile = (char*)"in-mem buffer";
         p->flags |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
     }
@@ -600,7 +603,6 @@ ag_scm_out_line( void )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expOutput.c */
