@@ -1,6 +1,9 @@
 
 /*
- *  $Id: expPrint.c,v 4.6 2005/12/05 20:51:37 bkorb Exp $
+ *  $Id: expPrint.c,v 4.16 2006/12/15 03:01:10 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-12-14 18:21:28 bkorb"
+ *  Last Committed:    $Date: 2006/12/15 03:01:10 $
  *
  *  The following code is necessary because the user can give us
  *  a printf format requiring a string pointer yet fail to provide
@@ -10,7 +13,7 @@
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -30,9 +33,10 @@
  */
 
 static sigjmp_buf printJumpEnv;
+static int        printJumpSignal = 0;
+
 static void   printFault( int sig );
 static ssize_t safePrintf( char** pzBuf, char* pzFmt, void** argV );
-tSCC pzFormatName[] = "format";
 
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
@@ -46,6 +50,7 @@ safePrintf( char** ppzBuf, char* pzFmt, void** argV );
 static void
 printFault( int sig )
 {
+    printJumpSignal = sig;
     siglongjmp( printJumpEnv, sig );
 }
 
@@ -53,9 +58,15 @@ printFault( int sig )
 static ssize_t
 safePrintf( char** ppzBuf, char* pzFmt, void** argV )
 {
-    tSCC zBadArgs[]  = "Bad args to sprintf";
-    tSCC zBadFmt[]   = "%s ERROR:  %s processing printf format:\n\t%s\n";
-
+#if ! defined(DEBUG_ENABLED)
+    /*
+     *  In normal operation (or during AutoGen testing), seg faults during the
+     *  printf operation are caused by bad input data.  During AutoGen
+     *  development, we do not supply bad printf arguments, so we want to
+     *  capture any segfaults when they happen with the correct stack trace.
+     *  Therefore, during AutoGen development, we do not protect against seg
+     *  faults.
+     */
     struct sigaction  saSave1;
     struct sigaction  saSave2;
 
@@ -69,13 +80,15 @@ safePrintf( char** ppzBuf, char* pzFmt, void** argV )
         sigaction( SIGSEGV, &sa, &saSave2 );
     }
 
-    /*
-     *  IF the sprintfv call below is going to address fault,
-     *  THEN ...
-     */
     {
-        int faultType = sigsetjmp( printJumpEnv, 0 );
-        if (faultType != 0) {
+        tSCC zBadArgs[] = "Bad args to sprintf";
+        tSCC zBadFmt[]  = "%s ERROR:  %s processing printf format:\n\t%s\n";
+
+        /*
+         *  IF the sprintfv call below is going to address fault,
+         *  THEN ...
+         */
+        if (sigsetjmp( printJumpEnv, 0 ) != 0) {
 #ifndef HAVE_STRSIGNAL
             extern char* strsignal(int signo);
 #endif
@@ -84,7 +97,8 @@ safePrintf( char** ppzBuf, char* pzFmt, void** argV )
              *  THEN perform that fprintf
              */
             if (sigsetjmp( printJumpEnv, 0 ) == 0)
-                fprintf(pfTrace, zBadFmt, pzProg, strsignal(faultType), pzFmt);
+                fprintf(pfTrace, zBadFmt, pzProg,
+                        strsignal(printJumpSignal), pzFmt);
 
             /*
              *  The "sprintfv" command below faulted, so we exit
@@ -92,15 +106,17 @@ safePrintf( char** ppzBuf, char* pzFmt, void** argV )
             AG_ABEND( zBadArgs );
         }
     }
+#endif /* ! defined(DEBUG_ENABLED) */
 
     {
-        size_t printSize = asprintfv( ppzBuf, pzFmt,
-                                      (snv_constpointer*)argV );
-        if ((printSize & ~0xFFFFFF) != 0)
+        size_t printSize = asprintfv( ppzBuf, pzFmt, (snv_constpointer*)argV );
+        if ((printSize & ~0xFFFFFU) != 0) /* 1MB max */
             AG_ABEND( aprf( "asprintfv returned 0x%08X\n", printSize ));
 
+#if ! defined(DEBUG_ENABLED)
         sigaction( SIGBUS,  &saSave1, NULL );
         sigaction( SIGSEGV, &saSave2, NULL );
+#endif
         return printSize;
     }
 }
@@ -126,7 +142,7 @@ run_printf( char* pzFmt, int len, SCM alist )
         switch (gh_type_e( car )) {
         default:
         case GH_TYPE_UNDEFINED:
-            *(argp++) = "???";
+            *(argp++) = (char*)"???";
             break;
 
         case GH_TYPE_BOOLEAN:
@@ -138,7 +154,7 @@ run_printf( char* pzFmt, int len, SCM alist )
             break;
 
         case GH_TYPE_PAIR:
-            *(argp++) = "..";
+            *(argp++) = (char*)"..";
             break;
 
         case GH_TYPE_NUMBER:
@@ -151,12 +167,12 @@ run_printf( char* pzFmt, int len, SCM alist )
             break;
 
         case GH_TYPE_PROCEDURE:
-            *(argp++) = "(*)()";
+            *(argp++) = (char*)"(*)()";
             break;
 
         case GH_TYPE_VECTOR:
         case GH_TYPE_LIST:
-            *(argp++) = "...";
+            *(argp++) = (char*)"...";
             break;
         }
     }
@@ -167,7 +183,7 @@ run_printf( char* pzFmt, int len, SCM alist )
      */
     {
         char*   pzBuf;
-        ssize_t bfSize = safePrintf( &pzBuf, pzFmt, arglist );
+        size_t  bfSize = safePrintf( &pzBuf, pzFmt, arglist );
         res = AG_SCM_STR2SCM( pzBuf, bfSize );
         free( pzBuf );
     }
@@ -193,7 +209,7 @@ SCM
 ag_scm_sprintf( SCM fmt, SCM alist )
 {
     int   list_len = scm_ilength( alist );
-    char* pzFmt    = ag_scm2zchars( fmt, pzFormatName );
+    char* pzFmt    = ag_scm2zchars( fmt, zFormat );
 
     if (list_len <= 0)
         return fmt;
@@ -219,7 +235,7 @@ SCM
 ag_scm_printf( SCM fmt, SCM alist )
 {
     int   list_len = scm_ilength( alist );
-    char* pzFmt    = ag_scm2zchars( fmt, pzFormatName );
+    char* pzFmt    = ag_scm2zchars( fmt, zFormat );
 
     gh_display( run_printf( pzFmt, list_len, alist ));
     return SCM_UNDEFINED;
@@ -243,7 +259,7 @@ SCM
 ag_scm_fprintf( SCM port, SCM fmt, SCM alist )
 {
     int   list_len = scm_ilength( alist );
-    char* pzFmt    = ag_scm2zchars( fmt, pzFormatName );
+    char* pzFmt    = ag_scm2zchars( fmt, zFormat );
     SCM   res      = run_printf( pzFmt, list_len, alist );
 
     return  scm_display( res, port );
@@ -275,9 +291,8 @@ ag_scm_hide_email( SCM display, SCM eaddr )
         "document.write('\" >%s</a>');\n"
         "//-->\n</script>";
     tSCC zFmt[]   = "&#%d;";
-    char*  pzDisp = ag_scm2zchars( display, pzFormatName );
-    char*  pzEadr = ag_scm2zchars( eaddr,   pzFormatName );
-    SCM    res;
+    char*  pzDisp = ag_scm2zchars( display, zFormat );
+    char*  pzEadr = ag_scm2zchars( eaddr,   zFormat );
     size_t str_size = (strlen( pzEadr ) * sizeof( zFmt ))
             + sizeof( zStrt ) + sizeof( zEnd ) + strlen( pzDisp );
 
@@ -295,7 +310,7 @@ ag_scm_hide_email( SCM display, SCM eaddr )
 
     pzScan += sprintf( pzScan, zEnd, pzDisp );
 
-    return AG_SCM_STR2SCM( pzRes, pzScan - pzRes );
+    return AG_SCM_STR2SCM( pzRes, (size_t)(pzScan - pzRes));
 }
 
 
@@ -329,7 +344,7 @@ ag_scm_hide_email( SCM display, SCM eaddr )
 SCM
 ag_scm_format_arg_count( SCM fmt )
 {
-    char* pzFmt = ag_scm2zchars( fmt, pzFormatName );
+    char* pzFmt = ag_scm2zchars( fmt, zFormat );
     int   ct    = 0;
     for (;;) {
         switch (*(pzFmt++)) {
@@ -347,7 +362,6 @@ ag_scm_format_arg_count( SCM fmt )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expPrint.c */
