@@ -1,31 +1,25 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Fri Feb  3 08:01:18 PST 2006
+ * Generated Sat Jan 27 07:01:22 PST 2007
  */
 #ifndef AGEN5_PROTO_H_GUARD
-#define AGEN5_PROTO_H_GUARD
+#define AGEN5_PROTO_H_GUARD 1
 #ifndef LOCAL
 #  define LOCAL extern
 #  define REDEF_LOCAL 1
 #else
 #  undef  REDEF_LOCAL
 #endif
-/*
- *  Extracted from agCgi.c
- */
+/*\n *  Extracted from agCgi.c\n */
 LOCAL void
 loadCgi( void );
 
-/*
- *  Extracted from agInit.c
- */
+/*\n *  Extracted from agInit.c\n */
 LOCAL void
 initialize( int arg_ct, char** arg_vec );
 
-/*
- *  Extracted from agShell.c
- */
+/*\n *  Extracted from agShell.c\n */
 LOCAL void
 closeServer( void );
 
@@ -41,13 +35,14 @@ LOCAL pid_t
 openServerFP( tpfPair* pfPair, tCC** ppArgs );
 
 LOCAL char*
-runShell( const char*  pzCmd );
+runShell( char const*  pzCmd );
 
-/*
- *  Extracted from agUtils.c
- */
+/*\n *  Extracted from agUtils.c\n */
 LOCAL char*
-aprf( const char* pzFmt, ... );
+aprf( char const* pzFmt, ... );
+
+LOCAL char*
+mkstempPat( void );
 
 LOCAL void
 doOptions( int arg_ct, char** arg_vec );
@@ -64,9 +59,7 @@ skipScheme( tCC* pzSrc,  tCC* pzEnd );
 LOCAL tCC*
 skipExpression( tCC* pzSrc, size_t len );
 
-/*
- *  Extracted from autogen.c
- */
+/*\n *  Extracted from autogen.c\n */
 LOCAL void
 ag_abend_at( tCC* pzMsg
 #ifdef DEBUG_ENABLED
@@ -74,17 +67,25 @@ ag_abend_at( tCC* pzMsg
 #endif
     );
 
-/*
- *  Extracted from defDirect.c
- */
+LOCAL void *
+ao_malloc (size_t sz);
+
+LOCAL void *
+ao_realloc (void *p, size_t sz);
+
+LOCAL void
+ao_free (void *p);
+
+LOCAL char *
+ao_strdup (char const * str);
+
+/*\n *  Extracted from defDirect.c\n */
 LOCAL char*
 processDirective( char* pzScan );
 
-/*
- *  Extracted from defFind.c
- */
+/*\n *  Extracted from defFind.c\n */
 LOCAL int
-canonicalizeName( char* pzD, const char* pzS, int srcLen );
+canonicalizeName( char* pzD, char const* pzS, int srcLen );
 
 LOCAL tDefEntry*
 findDefEntry( char* pzName, ag_bool* pIsIndexed );
@@ -92,18 +93,14 @@ findDefEntry( char* pzName, ag_bool* pIsIndexed );
 LOCAL tDefEntry**
 findEntryList( char* pzName );
 
-/*
- *  Extracted from defLex.c
- */
+/*\n *  Extracted from defLex.c\n */
 LOCAL te_dp_event
 yylex( void );
 
 LOCAL void
 yyerror( char* s );
 
-/*
- *  Extracted from defLoad.c
- */
+/*\n *  Extracted from defLoad.c\n */
 LOCAL void
 freeEntry( tDefEntry* pDE );
 
@@ -119,57 +116,43 @@ readDefines( void );
 LOCAL void
 unloadDefs( void );
 
-/*
- *  Extracted from expGuile.c
- */
+/*\n *  Extracted from expGuile.c\n */
 LOCAL teGuileType
 gh_type_e( SCM typ );
 
 LOCAL SCM
 ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line );
 
-/*
- *  Extracted from expOutput.c
- */
+/*\n *  Extracted from expOutput.c\n */
 LOCAL void
 removeWriteAccess( int fd );
 
-/*
- *  Extracted from expPrint.c
- */
+/*\n *  Extracted from expPrint.c\n */
 LOCAL SCM
 run_printf( char* pzFmt, int len, SCM alist );
 
-/*
- *  Extracted from funcDef.c
- */
+/*\n *  Extracted from funcDef.c\n */
 LOCAL void
 parseMacroArgs( tTemplate* pT, tMacro* pMac );
 
-/*
- *  Extracted from funcEval.c
- */
-LOCAL char*
+/*\n *  Extracted from funcEval.c\n */
+LOCAL tCC*
 resolveSCM( SCM s );
 
-LOCAL char*
+LOCAL tCC*
 evalExpression( ag_bool* pMustFree );
 
 LOCAL SCM
-eval( const char* pzExpr );
+eval( char const* pzExpr );
 
-/*
- *  Extracted from loadPseudo.c
- */
+/*\n *  Extracted from loadPseudo.c\n */
 LOCAL tCC*
 doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo );
 
 LOCAL tCC*
 loadPseudoMacro( tCC* pzData, tCC* pzFileName );
 
-/*
- *  Extracted from tpLoad.c
- */
+/*\n *  Extracted from tpLoad.c\n */
 LOCAL tTemplate*
 findTemplate( tCC* pzTemplName );
 
@@ -185,15 +168,11 @@ unloadTemplate( tTemplate* pT );
 LOCAL void
 cleanup( tTemplate* pTF );
 
-/*
- *  Extracted from tpParse.c
- */
+/*\n *  Extracted from tpParse.c\n */
 LOCAL tMacro*
 parseTemplate( tMacro* pM, tCC** ppzText );
 
-/*
- *  Extracted from tpProcess.c
- */
+/*\n *  Extracted from tpProcess.c\n */
 LOCAL void
 generateBlock( tTemplate*   pT,
                tMacro*      pMac,
@@ -209,5 +188,4 @@ closeOutput( ag_bool purge );
 #  undef LOCAL
 #  define LOCAL
 #endif
-
 #endif /* AGEN5_PROTO_H_GUARD */
