@@ -1,7 +1,7 @@
 
 /*
- *  $Id: autoopts.c,v 4.19 2006/12/10 16:43:00 bkorb Exp $
- *  Time-stamp:      "2006-12-02 09:00:13 bkorb"
+ *  $Id: autoopts.c,v 4.21 2007/01/18 05:32:13 bkorb Exp $
+ *  Time-stamp:      "2007-01-17 16:39:29 bkorb"
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -153,6 +153,8 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
      */
     tOptDesc* pOD = pOptState->pOD;
     tOptProc* pOP = pOD->pOptProc;
+    if (pOD->fOptState & OPTST_ALLOC_ARG)
+        AGFREE(pOD->optArg.argString);
 
     pOD->optArg.argString = pOptState->pzOptArg;
 
@@ -927,9 +929,9 @@ checkConsistency( tOptions* pOpts )
 
             errCt++;
             if (pOD->optMinCt > 1)
-                fprintf( stderr, zNotEnough, pOD->pz_Name, pOD->optMinCt );
+                 fprintf( stderr, zNotEnough, pOD->pz_Name, pOD->optMinCt );
             else fprintf( stderr, zNeedOne, pOD->pz_Name );
-           } while (0);
+        } while (0);
 
         if (--oCt <= 0)
             break;
