@@ -1,7 +1,8 @@
 
 /*
  *  xml2ag.c
- *  $Id: xml2ag.c,v 4.6 2006/06/24 23:36:08 bkorb Exp $
+ *  $Id: xml2ag.c,v 4.9 2006/11/27 01:52:23 bkorb Exp $
+ *  Time-stamp:         "2006-11-26 16:53:13 bkorb"
  *  This is the main routine for xml2ag.
  *
  *  xml2ag copyright 2002-2006 Bruce Korb
@@ -68,7 +69,7 @@ static void
 emitIndentation( void );
 
 static char*
-trim( const char* pzSrc, size_t* pSz );
+trim( char const* pzSrc, size_t* pSz );
 
 static xmlNodePtr
 printHeader( xmlDocPtr pDoc );
@@ -82,16 +83,16 @@ printNode( xmlNodePtr pNode );
 static void
 printChildren( xmlNodePtr pNode );
 /* = = = END-STATIC-FORWARD = = = */
-#define TRIM(s,psz) trim( (const char*)(s), (size_t*)(psz) )
+#define TRIM(s,psz) trim( (char const*)(s), (size_t*)(psz) )
 
-extern void forkAutogen( const char* pzInput );
+extern void forkAutogen( char const* pzInput );
 
 
 int
 main( int argc, char** argv )
 {
     xmlDocPtr   pDoc;
-    const char* pzFile = NULL;
+    char const* pzFile = NULL;
 
     {
         int ct = optionProcess( &xml2agOptions, argc, argv );
@@ -138,7 +139,7 @@ main( int argc, char** argv )
     }
 
     {
-        static const char z_not_doc[] =
+        static char const z_not_doc[] =
             "/* type %d doc is not DOCUMENT or HTML_DOCUMENT */\n";
 
         xmlNodePtr pRoot = printHeader( pDoc );
@@ -173,12 +174,12 @@ loadFile( FILE* fp, size_t* pzSize )
         }
 
         if (mem == NULL) {
-            fprintf( stderr, "Cannot allocate %d byte bufer\n", asz );
+            fprintf(stderr, "Cannot allocate %d byte bufer\n", (int)asz);
             exit( EXIT_FAILURE );
         }
 
         {
-            size_t rdct = fread( mem + usz, 1, CHUNK_SZ, fp );
+            size_t rdct = fread(mem + usz, (size_t)1, (size_t)CHUNK_SZ, fp);
             usz += rdct;
             if (rdct < CHUNK_SZ)
                 break;
@@ -199,7 +200,7 @@ emitIndentation( void )
 
 
 static char*
-trim( const char* pzSrc, size_t* pSz )
+trim( char const* pzSrc, size_t* pSz )
 {
     static char   zNil[1] = "";
     static char*  pzData  = NULL;
@@ -217,7 +218,7 @@ trim( const char* pzSrc, size_t* pSz )
     while (isspace( *pzSrc ))  pzSrc++;
 
     {
-        const char* pzEnd = pzSrc + strlen( pzSrc );
+        char const* pzEnd = pzSrc + strlen( pzSrc );
         while ((pzEnd > pzSrc) && isspace( pzEnd[-1] ))  pzEnd--;
 
         if (pzEnd <= pzSrc) {
@@ -232,7 +233,7 @@ trim( const char* pzSrc, size_t* pSz )
      *  big enough to hold the newly formed string.
      */
     {
-        const char* pz = pzSrc;
+        char const* pz = pzSrc;
         for (;;) {
             pz += strcspn( pz, "'\\" );
             if (*(pz++) == NUL)
@@ -281,7 +282,7 @@ static xmlNodePtr
 printHeader( xmlDocPtr pDoc )
 {
     tSCC zDef[] = "AutoGen Definitions %s%s;\n";
-    const char* pzSfx = ".tpl";
+    char const* pzSfx = ".tpl";
 
     xmlNodePtr pRootNode = xmlDocGetRootElement( pDoc );
     xmlChar*   pTpl = NULL;
@@ -421,7 +422,7 @@ printNode( xmlNodePtr pNode )
             char* pz = strstr( pzTxt, "*/" );
             if (pz == NULL)
                 break;
-            fwrite( pzTxt, (unsigned)((pz - pzTxt) + 1), 1, outFp );
+            fwrite(pzTxt, (size_t)((pz - pzTxt) + 1), (size_t)1, outFp);
             pzTxt = pz+1;
             fputc( ' ', outFp );
         }
@@ -472,7 +473,6 @@ printChildren( xmlNodePtr pNode )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of xml2ag/xml2ag.c */
